pub struct QMediaType(pub MediaType, pub Option<f32>);
A MediaType with an associated quality value.

Tuple Fields

0: MediaType1: Option<f32>

Implementations

Retrieve the weight of the media type, if there is any.

Example
use rocket::http::{MediaType, QMediaType};

let q_type = QMediaType(MediaType::HTML, Some(0.3));
assert_eq!(q_type.weight(), Some(0.3));

Retrieve the weight of the media type or a given default value.

Example
use rocket::http::{MediaType, QMediaType};

let q_type = QMediaType(MediaType::HTML, Some(0.3));
assert_eq!(q_type.weight_or(0.9), 0.3);

let q_type = QMediaType(MediaType::HTML, None);
assert_eq!(q_type.weight_or(0.9), 0.9);

Borrow the internal MediaType.

Example
use rocket::http::{MediaType, QMediaType};

let q_type = QMediaType(MediaType::HTML, Some(0.3));
assert_eq!(q_type.media_type(), &MediaType::HTML);

Methods from Deref<Target = MediaType>

Returns the top-level type for this media type. The return type, UncasedStr, has caseless equality comparison and hashing.

Example
use rocket::http::MediaType;

let plain = MediaType::Plain;
assert_eq!(plain.top(), "text");
assert_eq!(plain.top(), "TEXT");
assert_eq!(plain.top(), "Text");

Returns the subtype for this media type. The return type, UncasedStr, has caseless equality comparison and hashing.

Example
use rocket::http::MediaType;

let plain = MediaType::Plain;
assert_eq!(plain.sub(), "plain");
assert_eq!(plain.sub(), "PlaIN");
assert_eq!(plain.sub(), "pLaIn");

Returns a u8 representing how specific the top-level type and subtype of this media type are.

The return value is either 0, 1, or 2, where 2 is the most specific. A 0 is returned when both the top and sublevel types are *. A 1 is returned when only one of the top or sublevel types is *, and a 2 is returned when neither the top or sublevel types are *.

Example
use rocket::http::MediaType;

let mt = MediaType::Plain;
assert_eq!(mt.specificity(), 2);

let mt = MediaType::new("text", "*");
assert_eq!(mt.specificity(), 1);

let mt = MediaType::Any;
assert_eq!(mt.specificity(), 0);

Compares self with other and returns true if self and other are exactly equal to each other, including with respect to their parameters and their order.

This is different from the PartialEq implementation in that it considers parameters. In particular, Eq implies PartialEq but PartialEq does not imply Eq. That is, if PartialEq returns false, this function is guaranteed to return false. Similarly, if exact_eq returns true, PartialEq is guaranteed to return true. However, if PartialEq returns true, exact_eq function may or may not return true.

Example
use rocket::http::MediaType;

let plain = MediaType::Plain;
let plain2 = MediaType::new("text", "plain").with_params(("charset", "utf-8"));
let just_plain = MediaType::new("text", "plain");

// The `PartialEq` implementation doesn't consider parameters.
assert!(plain == just_plain);
assert!(just_plain == plain2);
assert!(plain == plain2);

// While `exact_eq` does.
assert!(!plain.exact_eq(&just_plain));
assert!(!plain2.exact_eq(&just_plain));
assert!(plain.exact_eq(&plain2));

Returns an iterator over the (key, value) pairs of the media type’s parameter list. The iterator will be empty if the media type has no parameters.

Example

The MediaType::Plain type has one parameter: charset=utf-8:

use rocket::http::MediaType;

let plain = MediaType::Plain;
let (key, val) = plain.params().next().unwrap();
assert_eq!(key, "charset");
assert_eq!(val, "utf-8");

The MediaType::PNG type has no parameters:

use rocket::http::MediaType;

let png = MediaType::PNG;
assert_eq!(png.params().count(), 0);

Returns the first parameter with name name, if there is any.

Returns the most common file extension associated with the Media-Type self if it is known. Otherwise, returns None . The currently recognized extensions are identical to those in MediaType::from_extension() with the most common extension being the first extension appearing in the list for a given Media-Type .

Example

Known extension:

use rocket::http::MediaType;

assert_eq!(MediaType::JSON.extension().unwrap(), "json");
assert_eq!(MediaType::JPEG.extension().unwrap(), "jpeg");
assert_eq!(MediaType::JPEG.extension().unwrap(), "JPEG");
assert_eq!(MediaType::PDF.extension().unwrap(), "pdf");

An unknown extension:

use rocket::http::MediaType;

let foo = MediaType::new("foo", "bar");
assert!(foo.extension().is_none());

Returns true if this MediaType is known to Rocket. In other words, returns true if there is an associated constant for self.

Returns true if the top-level and sublevel types of self are the same as those of MediaType::Any .

Returns true if the top-level and sublevel types of self are the same as those of MediaType::Binary .

Returns true if the top-level and sublevel types of self are the same as those of MediaType::Bytes .

Returns true if the top-level and sublevel types of self are the same as those of MediaType::HTML .

Returns true if the top-level and sublevel types of self are the same as those of MediaType::Plain .

Returns true if the top-level and sublevel types of self are the same as those of MediaType::Text .

Returns true if the top-level and sublevel types of self are the same as those of MediaType::JSON .

Returns true if the top-level and sublevel types of self are the same as those of MediaType::MsgPack .

Returns true if the top-level and sublevel types of self are the same as those of MediaType::Form .

Returns true if the top-level and sublevel types of self are the same as those of MediaType::JavaScript .

Returns true if the top-level and sublevel types of self are the same as those of MediaType::CSS .

Returns true if the top-level and sublevel types of self are the same as those of MediaType::FormData .

Returns true if the top-level and sublevel types of self are the same as those of MediaType::XML .

Returns true if the top-level and sublevel types of self are the same as those of MediaType::CSV .

Returns true if the top-level and sublevel types of self are the same as those of MediaType::PNG .

Returns true if the top-level and sublevel types of self are the same as those of MediaType::GIF .

Returns true if the top-level and sublevel types of self are the same as those of MediaType::BMP .

Returns true if the top-level and sublevel types of self are the same as those of MediaType::JPEG .

Returns true if the top-level and sublevel types of self are the same as those of MediaType::WEBP .

Returns true if the top-level and sublevel types of self are the same as those of MediaType::AVIF .

Returns true if the top-level and sublevel types of self are the same as those of MediaType::SVG .

Returns true if the top-level and sublevel types of self are the same as those of MediaType::Icon .

Returns true if the top-level and sublevel types of self are the same as those of MediaType::WEBM .

Returns true if the top-level and sublevel types of self are the same as those of MediaType::WEBA .

Returns true if the top-level and sublevel types of self are the same as those of MediaType::OGG .

Returns true if the top-level and sublevel types of self are the same as those of MediaType::FLAC .

Returns true if the top-level and sublevel types of self are the same as those of MediaType::WAV .

Returns true if the top-level and sublevel types of self are the same as those of MediaType::PDF .

Returns true if the top-level and sublevel types of self are the same as those of MediaType::TTF .

Returns true if the top-level and sublevel types of self are the same as those of MediaType::OTF .

Returns true if the top-level and sublevel types of self are the same as those of MediaType::WOFF .

Returns true if the top-level and sublevel types of self are the same as those of MediaType::WOFF2 .

Returns true if the top-level and sublevel types of self are the same as those of MediaType::JsonApi .

Returns true if the top-level and sublevel types of self are the same as those of MediaType::WASM .

Returns true if the top-level and sublevel types of self are the same as those of MediaType::TIFF .

Returns true if the top-level and sublevel types of self are the same as those of MediaType::AAC .

Returns true if the top-level and sublevel types of self are the same as those of MediaType::Calendar .

Returns true if the top-level and sublevel types of self are the same as those of MediaType::MPEG .

Returns true if the top-level and sublevel types of self are the same as those of MediaType::TAR .

Returns true if the top-level and sublevel types of self are the same as those of MediaType::GZIP .

Returns true if the top-level and sublevel types of self are the same as those of MediaType::MOV .

Returns true if the top-level and sublevel types of self are the same as those of MediaType::MP4 .

Returns true if the top-level and sublevel types of self are the same as those of MediaType::ZIP .

Returns true if the top-level and sublevel types of self are the same as those of MediaType::EventStream .

Returns true if the top-level and sublevel types of self are the same as those of MediaType::Markdown .